@@ -3,6 +3,5 @@
 #' @name RANN-package
 #' @aliases RANN
 #' @seealso \code{\link{nn2}}
-#' @docType package
 #' @keywords package
-NULL
+"_PACKAGE"
